@@ -208,25 +208,40 @@ public:
     static QString description(const QString &regionCode);
 
     /**
-     * @since 4.6
+     * @since 5.95
+     *
+     * Returns the list of holidays that occur between @p startDate and @p endDate.
+     *
+     */
+    Holiday::List rawHolidaysWithAstroSeasons(const QDate &startDate, const QDate &endDate) const;
+
+    /**
+     * @since 5.97
      *
      * Returns the list of holidays that occur between @p startDate and @p endDate.
      */
-    Holiday::List holidays(const QDate &startDate, const QDate &endDate) const;
+    Holiday::List rawHolidays(const QDate &startDate, const QDate &endDate) const;
 
     /**
-     * @since 4.6
+     * @since 5.95
      *
      * Returns the list of holidays that occur on a @p date.
      */
-    Holiday::List holidays(const QDate &date) const;
+    Holiday::List rawHolidaysWithAstroSeasons(const QDate &date) const;
 
     /**
-     * @since 4.6
+     * @since 5.95
      *
      * Returns the list of holidays that occur in a Gregorian calendar year @p calendarYear.
      */
-    Holiday::List holidays(int calendarYear) const;
+    Holiday::List rawHolidaysWithAstroSeasons(int calendarYear) const;
+
+    /**
+     * @since 5.95
+     *
+     * Returns the list of holidays that occur between @p startDate and @p endDate and with @p category.
+     */
+    Holiday::List rawHolidays(const QDate &startDate, const QDate &endDate, const QString &category) const;
 
     /**
      * Checks whether there is any holiday defined for a @p date.
